.. _visualizing:

Visualizing Data
================

yt comes with a number of ways for visualizing one's data including slices,
projections, line plots, profiles, phase plots, volume rendering, 3D surfaces,
streamlines, and a google-maps-like interface for exploring one's dataset 
interactively.  

.. toctree::
   :maxdepth: 2

   plots
   callbacks
   manual_plotting
   volume_rendering
   hardware_volume_rendering
   sketchfab
   mapserver
   streamlines
   colormaps/index
   writing_fits_images
